GameInfo

Struct GameInfo 

pub struct GameInfo<'a> {
    pub _tab: Table<'a>,
}

Fields

_tab: Table<'a>

Implementations

Source

impl<'a> GameInfo<'a>

pub const VT_SECONDSELAPSED: VOffsetT = 4i16

pub const VT_GAMETIMEREMAINING: VOffsetT = 6i16

pub const VT_ISOVERTIME: VOffsetT = 8i16

pub const VT_ISUNLIMITEDTIME: VOffsetT = 10i16

pub const VT_ISROUNDACTIVE: VOffsetT = 12i16

pub const VT_ISKICKOFFPAUSE: VOffsetT = 14i16

pub const VT_ISMATCHENDED: VOffsetT = 16i16

pub const VT_WORLDGRAVITYZ: VOffsetT = 18i16

pub const VT_GAMESPEED: VOffsetT = 20i16

pub fn init_from_table(table: Table<'a>) -> Self

pub fn create<'bldr: 'args, 'args: 'mut_bldr, 'mut_bldr>( _fbb: &'mut_bldr mut FlatBufferBuilder<'bldr>, args: &'args GameInfoArgs, ) -> WIPOffset<GameInfo<'bldr>>

pub fn secondsElapsed(&self) -> f32

pub fn gameTimeRemaining(&self) -> f32

pub fn isOvertime(&self) -> bool

pub fn isUnlimitedTime(&self) -> bool

pub fn isRoundActive(&self) -> bool

True when cars are allowed to move, and during the pause menu. False during replays.

pub fn isKickoffPause(&self) -> bool

True when the clock is paused due to kickoff, but false during kickoff countdown. In other words, it is true while cars can move during kickoff. Note that if both players sit still, game clock start and this will become false.

pub fn isMatchEnded(&self) -> bool

Turns true after final replay, the moment the ‘winner’ screen appears. Remains true during next match countdown. Turns false again the moment the ‘choose team’ screen appears.

pub fn worldGravityZ(&self) -> f32

pub fn gameSpeed(&self) -> f32

Game speed multiplier, 1.0 is regular game speed.